/******************************************************************************
 File:    cpc.h
 Purpose: Header file for sample C language control programs for Hostess i,
          Hostess 186, and Smart Hostess.
 Company: Comtrol Corporation
 Author:  Craig Harrison
*******************************************************************************
 Copyright 1991-1993 Comtrol Corporation. All rights reserved.
 Subject to developers license agreement.
******************************************************************************/


/* ----- Interrupt Controller (PIC) Registers ----------------------------- */
#if defined HOSTESSi
   #define EOIVAL    0x20         /* end of interrupt value */
   #define SYS_TYPE  0x33         /* system interrupt vector type */
   #define INTCTL    0x9070       /* PIC port */
   #define INTCTL1   0x9071       /* PIC port for initialization command word */
#else if defined HOSTESS186 || defined SMARTH
   #define EOIVAL    0x8000       /* end of interrupt value */
   #define SYS_TYPE  0x0d         /* system interrupt vector type */
   #define INTCTL    0xff22       /* PIC port */
   #define INTCTL1   0xff28       /* PIC port for initialization command word */
#endif

/* ----- Timer Registers -------------------------------------------------- */
#if defined HOSTESSi
   #define CNT100       0x1e84    /* 100/sec counter value */
   #define CNT200       0x0f42    /* 200/sec counter value */
   #define TIM0_TYPE    0x34      /* timer 0 interrupt vector type */
   #define TIM1_TYPE    0x35      /* timer 1 interrupt vector type */
   #define TIM2_TYPE    0x36      /* timer 2 interrupt vector type */
   #define TIMER0       0x9074    /* timer 0 count reg address */
   #define TIMER1       0x9075    /* timer 1 count reg address */
   #define TIMER2       0x9076    /* timer 2 count reg address */
   #define TIM_CTL      0x9077    /* timer control word address*/
   #define TIM0_CTLWD   0x64      /* timer 0 control word */
   #define TIM1_CTLWD   0x74      /* timer 1 control word */
   #define TIM2_CTLWD   0xb4      /* timer 2 control word */
   #define MIN_TIMER    0         /* minimum timer number */
   #define MAX_TIMER    2         /* maximum timer number */

   typedef struct                 /* timer information */
   {
      int vector_type;            /* interrupt vector type number */
      int control_word;           /* counter control word */
      int count_reg;              /* counter register address */
   } TIMER_T;
#else if defined HOSTESS186 || defined SMARTH
   #define CNT100          0x4e20    /* 100/sec counter value */
   #define CNT200          0x2710    /* 200/sec counter value */
   #define TIM_CTLWD       0xe001    /* control word: EN, -INH, INT, -P, CONT */
   #define TIM0_TYPE       0x08      /* timer 0 interrupt vector type */
   #define TIM0_CTRL       0xff56    /* mode/control register */
   #define TIM0_MAX_CNTB   0xff54    /* max count B */
   #define TIM0_MAX_CNTA   0xff52    /* max count A */
   #define TIM0_CNT        0xff50    /* count register */
   #define TIM1_TYPE       0x12      /* timer 1 interrupt vector type */
   #define TIM1_CTRL       0xff5e    /* mode/control register */
   #define TIM1_MAX_CNTB   0xff5c    /* max count B */
   #define TIM1_MAX_CNTA   0xff5a    /* max count A */
   #define TIM1_CNT        0xff58    /* count register */
   #define TIM_INT_CTRL    0xff32    /* timer interrupt control register */
   #define MIN_TIMER       0         /* minimum timer number */
   #define MAX_TIMER       1         /* maximum timer number */

   typedef struct                 /* timer information */
   {
      int vector_type;            /* interrupt vector type number */
      int ctrl_reg;               /* mode/control register address */
      int maxcnta_reg;            /* max count A register address */
   } TIMER_T;
#endif

/* ----- SCC command register I/O addresses ------------------------------- */
#if defined HOSTESSi
   #define LN00_IO         0xe1f4
   #define LN01_IO         0xe1f0
   #define LN02_IO         0xe3f4
   #define LN03_IO         0xe3f0
   #define LN04_IO         0xe5f4
   #define LN05_IO         0xe5f0
   #define LN06_IO         0xe7f4
   #define LN07_IO         0xe7f0
   #define LN08_IO         0xe9f4
   #define LN09_IO         0xe9f0
   #define LN10_IO         0xebf4
   #define LN11_IO         0xebf0
   #define LN12_IO         0xedf4
   #define LN13_IO         0xedf0
   #define LN14_IO         0xeff4
   #define LN15_IO         0xeff0
#else if defined HOSTESS186 || defined SMARTH
   #define LN00_IO         0x0004
   #define LN01_IO         0x0000
   #define LN02_IO         0x0084
   #define LN03_IO         0x0080
   #define LN04_IO         0x0104
   #define LN05_IO         0x0100
   #define LN06_IO         0x0184
   #define LN07_IO         0x0180
#endif

/* ----- Other defines ---------------------------------------------------- */
#define C2SINT_REG      0xef60   /* COM uP to SYS uP interrupt register */
#define C2SINT_HI       0        /* value to set interrupt line high */
#define C2SINT_LOW      0x0008   /* value to set interrupt line low  */
#define OUTB            outportb /* instruction to write a byte to I/O space */
#define INB             inportb  /* instruction to read a byte from I/O space */
#define OUTW            outport  /* instruction to write a word to I/O space */
#define INW             inport   /* instruction to read a word from I/O space */
#define NUM_SYSCMD      4        /* number of system commands */
#define SCCBASE_TYPE    0x80     /* base interrupt vector type for line 0 SCC */
#define CLRSYSINT_REG   0x206    /* clear sys interrupt, Smart Hostess only */
#define FLAGCHAR         0x30      /* RS-485 flag character, marks end of message
                                    so line turnaround TBE_isr generated */
#if defined HOSTESSi
   #define EOI(port,value) OUTB(port,value) /* End of interrupt */
#else if defined HOSTESS186 || SMARTH
   #define EOI(port,value) OUTW(port,value) /* End of interrupt */
#endif

/* ----- SCC register defines --------------------------------------------- */
#define WR0      0
#define WR1      1
#define WR2      2
#define WR3      3
#define WR4      4
#define WR5      5
#define WR6      6
#define WR7      7
#define WR8      8
#define WR9      9
#define WR10     10
#define WR11     11
#define WR12     12
#define WR13     13
#define WR14     14
#define WR15     15

#define RR0      0
#define RR1      1
#define RR2      2
#define RR3      3
#define RR8      8
#define RR10     10
#define RR12     12
#define RR13     13
#define RR15     15

/* ----- Baud Rate Generator Time Constants - x16 Baud Rate Factor ------- */
/* (based on a 4.9152 MHz clock) */
#define BPS50           3070
#define BPS75           2046
#define BPS110          1394           /* 0.026 percent error */
#define BPS134          1144           /* 0.001 percent error */
#define BPS150          1022
#define BPS300          510
#define BPS600          254
#define BPS1200         126
#define BPS1800         83              ; 0.401 percent error
#define BPS2000         75              ; 1.06 percent error
#define BPS2400         62
#define BPS3600         41              ; 1.62 percent error
#define BPS4800         30
#define BPS7200         19              ; 1.75 percent error
#define BPS9600         14
#define BPS19200        6
#define BPS38400        2
#define BPS56000        1               ; 74.3 percent error
#define BPS76800        0

/* ----- Write Register Definitions (for basic asynchronous communications) */
/* Write Register 0 - command register */
#define RESET_EXT        0x10
#define RESET_TX_INT     0x28
#define ERROR_RESET      0x30
#define RESET_IUS        0x38

/* Write Register 1 - Tx/Rx interrupt and data transfer mode definition */
#define EXT_INT_ENABLE   0x01
#define TX_INT_ENABLE    0x02
#define PARITY_SPECIAL   0x04
#define RX_INT_ENABLE    0x10

/* Write Register 2 - interrupt vector */

/* Write Register 3 - Rx parameters and controls */
#define RX_ENABLE        0x01
#define RX5_BIT_CHAR     0x00
#define RX7_BIT_CHAR     0x40
#define RX6_BIT_CHAR     0x80
#define RX8_BIT_CHAR     0x0c0


/* Write Register 4 - Tx/Rx miscellaneous parameters and modes */
#define PARITY_ENABLE    0x01
#define PARITY_EVEN      0x02
#define PARITY_ODD       0x00
#define ONE_STOP_BIT     0x04
#define ONE$_STOP_BITS   0x08
#define TWO_STOP_BITS    0x0c
#define X16_CLOCK        0x40

/* Write Register 5 - Tx paramerameters and controls */
#define RTS              0x02
#define TX_ENABLE        0x08
#define BREAK            0x10
#define Tx5_BIT_CHAR     0x00
#define Tx7_BIT_CHAR     0x20
#define Tx6_BIT_CHAR     0x40
#define Tx8_BIT_CHAR     0x60
#define DTR              0x80

/* Write Register 6 - sync character or SDLC address field */

/* Write Register 7 - sync character or SDLC flag */

/* Write Register 8 - transmit buffer */

/* Write Register 9 - master interrupt control */
#define VIS              0x01
#define NV               0x02
#define DLC              0x04
#define MIE              0x08
#define STATUS_LO        0x00
#define STATUS_HI        0x10
#define RESET_CH_B       0x40
#define RESET_CH_A       0x80
#define HARDWARE_RESET   0xc0

/* Write Register 10 - miscellaneous Tx/Rx control bits */

/* Write Register 11 - clock mode control */
#define TX_CLK_EQ_BRG    0x10
#define RX_CLK_EQ_BRG    0x40

/* Write Register 12 - lower byte of baud generator time constant */

/* Write Register 13 - upper byte of baud generator time constant */

/* Write Register 14 - miscellaneous control bits */
#define BRG_ENABLE       0x01
#define BRG_EQ_SYS_CLK   0x02

/* Write Register 15 - external/STATUS interrupt control */
#define DCD_IE           0x08
#define CTS_IE           0x20
#define BREAK_IE         0x80

/* ----- Read Register Definitions (for basic asynCHronous communications) */
/* Read Register 0 - Tx/Rx BUFFER STATUS and external STATUS */
#define RX_BUFFER        0x01
#define TX_BUFFER        0x04
#define DCD_             0x08
#define CTS_             0x20
#define BREAK_COND       0x80

/* Read Register 1 - special receive condition STATUS */
#define ALLSENT          0x01
#define PARITY_ERROR     0x10
#define OVERRUN_ERROR    0x20
#define FRAMING_ERROR    0x40

/* Read Register 2 - interrupt vector */

/* Read Register 3 - interrupt pending STATUS */

/* Read Register 8 - receive data register */

/* Read Register 10 - miscellaneous STATUS bits */

/* Read Register 12 - value stored in WR12 */

/* Read Register 13 - value stored in WR13 */

/* Read Register 15 - value stored in WR15 */


/*---------------------------------------------------------------------------*/
/* These used only to make a control program > 64K in size for test purposes */
void bigfunc(void);
int bigfunc1(int a,int b,int c,int d,int e,int f);
int bigfunc2(int a,int b,int c,int d,int e,int f);